#
# spec file for package perl-Class-Tiny
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Class-Tiny
Version:        1.008
Release:        1.18
%define cpan_name Class-Tiny
Summary:        Minimalist class construction
License:        Apache-2.0
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DA/DAGOLDEN/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.96
%{perl_requires}

%description
This module offers a minimalist class construction kit in around 120 lines
of code. Here is a list of features:

  * defines attributes via import arguments

  * generates read-write accessors

  * supports lazy attribute defaults

  * supports custom accessors

  * superclass provides a standard 'new' constructor

  * 'new' takes a hash reference or list of key/value pairs

  * 'new' supports providing 'BUILDARGS' to customize constructor options

  * 'new' calls 'BUILD' for each class from parent to child

  * superclass provides a 'DESTROY' method

  * 'DESTROY' calls 'DEMOLISH' for each class from child to parent

Multiple-inheritance is possible, with superclass order determined via
mro::get_linear_isa.

It uses no non-core modules for any recent Perl. On Perls older than v5.10
it requires MRO::Compat. On Perls older than v5.14, it requires
Devel::GlobalDestruction.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes CONTRIBUTING.mkdn README
%license LICENSE

%changelog
* Sat Sep  5 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.008
  see /usr/share/doc/packages/perl-Class-Tiny/Changes
  1.008     2020-09-04 10:04:50-04:00 America/New_York
  - No changes since 1.007
  1.007     2020-09-02 07:02:55-04:00 America/New_York (TRIAL RELEASE)
    [DOCUMENTATION]
  - DEMOLISH docs incorrectly claimed that errors were thrown.  Updated to
    say that errors are rethrown.
* Sun Sep 11 2016 coolo@suse.com
- updated to 1.006
  see /usr/share/doc/packages/perl-Class-Tiny/Changes
  1.006     2016-09-10 14:47:49-04:00 America/New_York
  - No changes since 1.005
  1.005     2016-09-06 12:12:06-04:00 America/New_York (TRIAL RELEASE)
    [INTERNAL]
  - Optimize generated accessors (5%% to 25%% faster depending on
    combination of read vs write and default vs no-default).
* Wed Nov 11 2015 coolo@suse.com
- updated to 1.004
  see /usr/share/doc/packages/perl-Class-Tiny/Changes
  1.004     2015-10-30 10:33:59-04:00 America/New_York
  - No changes since 1.003
  1.003     2015-10-27 13:01:02-04:00 America/New_York (TRIAL RELEASE)
    [INTERNAL]
  - Refactored accessor generation to allow subclasses of Class::Tiny
    to implement alternate accessors.
* Sat Feb  7 2015 coolo@suse.com
- updated to 1.001
    [ADDED]
  - Added support for BUILDARGS for Moo(se) compatibility
    [INTERNAL]
  - Implements BUILDALL via method (was inline) for Moo(se) compatibility
* Fri Aug 15 2014 ncutler@suse.com
- re-checked license
- updated to 1.000 -- upstream changes since last check-in:
    1.000     2014-07-16 09:55:29-04:00 America/New_York
    [*** INCOMPATIBLE CHANGES ***]
  - Attributes for custom accessors *MUST* be declared for them to be
    set via the constructor.  It is no longer sufficient for a method of
    the same name to exist.
  - Unknown constructor arguments are ignored rather than fatal; they are
    not included in the object.  Special instructions for using BUILD to
    hide constructor arguments from validation are irrelevant and have
    been removed.
  - These changes make Class::Tiny-based classes easier to subclass by
    more advanced object frameworks like Moose or Moo.
    0.015     2014-07-13 23:10:47-04:00 America/New_York
    [CHANGED]
  - lowered minimum perl to 5.006
* Fri Nov 29 2013 coolo@suse.com
- updated to 0.014
    [FIXED]
  - put back a 'no warnings "once"' line that caused downstream warnings
    [DOCUMENTED]
  - expanded comparision to Object::Tiny and Class::Accessor
* Mon Nov 25 2013 coolo@suse.com
- updated to 0.012
  [DOCUMENTED]
  - added documentation notes about multiple inheritance
    and attribute defaults under subclassing
  [INTERNAL]
  - added tests for multiple inheritance
* Sat Oct  5 2013 coolo@suse.com
- initial package 0.011
  * created by cpanspec 1.78.07
